GamepadPlatform class abstract

The common platform interface for gamepads.

Inheritance
  • Object
  • PlatformInterface
  • GamepadPlatform
Implementers

Constructors

GamepadPlatform()
Constructs a GamepadPlatform.

Properties

buttonEvents → Stream<ButtonEvent>
A broadcast stream of events from a button of a gamepad.
no setter
dpadEvents → Stream<DpadEvent>
A broadcast stream of events from the dpad of a gamepad.
no setter
hashCode → int
The hash code for this object.
no setterinherited
joystickEvents → Stream<JoystickEvent>
A broadcast stream of events from a joystick of a gamepad.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerEvents → Stream<TriggerEvent>
A broadcast stream of events from a trigger of a gamepad.
no setter

Methods

blockControl(Enum control) → Future<void>
A method to temporarily block control transmissions to a previously set internet address on the platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetAddress() → Future<void>
A method to reset a previously set internet address on the platform.
resumeControl(Enum control, [bool safe = true]) → Future<bool>
A method to either resume safe and therefore blocked or stopped control transmissions to a previously set internet address on the platform.
setAddress(InternetAddress connection) → Future<void>
A method to set an internet address on the platform.
stopControl(Enum control) → Future<void>
A method to completely stop control transmissions to a previously set internet address on the platform.
toString() → String
A string representation of this object.
inherited
turnScreenOff() → Future<bool>
A method to turn the screen's brightness of the device to lowest setting possible.
turnScreenOn() → Future<bool>
A method to turn the screen's brightness of the device to the user's defaults.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ GamepadPlatform
The default instance of GamepadPlatform to use.
getter/setter pair